from django.conf.urls import patterns, include, url
from django.views.decorators.cache import cache_page
from django.views.generic import TemplateView
from django.contrib.sites.models import Site
from django.contrib.auth.models import Group
from django.contrib import admin

from duat.views import post,view,generate_js

admin.autodiscover()
admin.site.unregister(Site)
admin.site.unregister(Group)

# 1 day cache
DEFAULT_CACHE = 60 * 60 * 24

urlpatterns = patterns('',
    # home page
    url(r'^$',TemplateView.as_view(template_name='duat/home.html')),

	# generated javascript
    url(r'^project/(?P<project_name>[\w-]+)/feedback\.js$', 
        cache_page(DEFAULT_CACHE)(generate_js), 
        name='duat-feedback', 
        kwargs={'filename':'duat/feedback.js'}),

    url(r'^js/admin\.js$', 
        cache_page(DEFAULT_CACHE)(generate_js),
        name='duat-admin',
        kwargs={'filename':'duat/admin.js',
                'project_name':None}),

    url(r'^project/(?P<project_name>[\w-]+)/submit$',
        post, 
        name='duat-post'),
    
    url(r'^view/(?P<project_name>[\w-]+)/(?P<id>\d+)/$',
        cache_page(DEFAULT_CACHE)(view),
        name='duat-view'),

    url(r'^admin/', include(admin.site.urls)),
)



import re
 
from django.utils.text import compress_string
from django.utils.cache import patch_vary_headers
 
from django import http
 
try:
    import settings 
    XS_SHARING_ALLOWED_ORIGINS = settings.XS_SHARING_ALLOWED_ORIGINS
    XS_SHARING_ALLOWED_METHODS = settings.XS_SHARING_ALLOWED_METHODS
    XS_SHARING_ALLOWED_HEADERS = settings.XS_SHARING_ALLOWED_HEADERS
except:
    XS_SHARING_ALLOWED_ORIGINS = '*'
    XS_SHARING_ALLOWED_METHODS = ['POST','GET','OPTIONS', 'PUT', 'DELETE']
    XS_SHARING_ALLOWED_HEADERS = ['Origin', 'Content-Type', 'Accept']
 
 
class XsSharing(object):
    """
        This middleware allows cross-domain XHR using the html5 postMessage API.
         
 
        Access-Control-Allow-Origin: http://foo.example
        Access-Control-Allow-Methods: POST, GET, OPTIONS, PUT, DELETE
    """
    def process_request(self, request):
 
        if 'HTTP_ACCESS_CONTROL_REQUEST_METHOD' in request.META:
            response = http.HttpResponse()
            response['Access-Control-Allow-Origin']  = XS_SHARING_ALLOWED_ORIGINS 
            response['Access-Control-Allow-Methods'] = ",".join( XS_SHARING_ALLOWED_METHODS ) 
            response['Access-Control-Allow-Headers'] = ",".join( XS_SHARING_ALLOWED_HEADERS ) 
            
            return response
 
        return None
 
    def process_response(self, request, response):
        # Avoid unnecessary work
        if response.has_header('Access-Control-Allow-Origin'):
            return response
 
        response['Access-Control-Allow-Origin']  = XS_SHARING_ALLOWED_ORIGINS 
        response['Access-Control-Allow-Methods'] = ",".join( XS_SHARING_ALLOWED_METHODS )
        response['Access-Control-Allow-Headers'] = ",".join( XS_SHARING_ALLOWED_HEADERS ) 
 
        return response
